# Test the endpoints.
@server = http://localhost:3000

###
GET {{server}}/?query=b gratis
###
# List accounts
GET {{server}}/?query=b%20--flat%20--empty%20--no-total
###
# Shutdown
GET {{server}}/shutdown
###